@@ -21,7 +21,10 @@ NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE."""
-from sample.sample import SAMPLE
+try:
+  from sample.sample import SAMPLE
+except ModuleNotFoundError:
+  pass
 
 
-__version__ = "0.0.2"
+__version__ = "0.3.0"
